@@ -257,6 +257,24 @@ class LocalCommands(object):
             'Instance running!\nVisit https://127.0.0.1:5000', fg='green')
         server.wait()
 
+    def destroy(self):
+        """Destroys a virtualenv (if created with pipenv) and containers."""
+        try:
+            subprocess.run(['pipenv', '--rm'], check=True)
+            click.secho('Virtual environment destroyed', fg='green')
+        except subprocess.CalledProcessError:
+            click.secho('The virtual environment was '
+                        'not removed as it was not '
+                        'created by pipenv', fg='red')
+
+        docker_helper = DockerHelper(
+            self.cli_config.get_project_shortname(),
+            local=True)
+
+        self.cli_config.update_services_setup(False)
+        docker_helper.destroy_containers()
+        click.secho('Destroyed containers...', fg='green')
+
 
 class ContainerizedCommands(object):
     """Containerized environment CLI commands."""
@@ -314,8 +332,13 @@ class ContainerizedCommands(object):
         if not locked:
             subprocess.run(command, check=True)
 
-    def containerize(self, pre, force, install):
+    def containerize(self, pre, force, install, stop):
         """Launch fully containerized application."""
+        if stop:
+            self.docker_helper.stop_containers()
+            click.secho("Stopping containers...", fg="green")
+            return
+
         self._lock_python_dependencies(pre)
 
         click.secho('Making sure containers are up...', fg='green')
@@ -387,3 +410,17 @@ class ContainerizedCommands(object):
         # container mode ensures the containers are up
         self.docker_helper.execute_cli_command(
             project_shortname, 'invenio rdm-records demo')
+
+    def destroy(self):
+        """Destroys the instance's virtualenv and containers."""
+        try:
+            subprocess.run(['pipenv', '--rm'], check=True)
+            click.secho('Virtual environment destroyed', fg='green')
+        except subprocess.CalledProcessError:
+            click.secho('The virtual environment was '
+                        'not removed as it was not '
+                        'created by pipenv', fg='red')
+
+        self.docker_helper.destroy_containers()
+        self.cli_config.update_services_setup(False)
+        click.secho('Destroyed containers...', fg='green')
